"""
Setup script for ggpubpy.

This file is kept for backward compatibility.
The actual configuration is in pyproject.toml.

# Note: mypy may report a "library stubs" error for setuptools.
# This can be resolved by running: pip install types-setuptools
"""

from setuptools import setup

if __name__ == "__main__":
    setup()
